/*******************************************************************************
* File Name: clock.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "clock.h"


/*******************************************************************************
* Function Name: clock_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void clock_Write(uint8 value) 
{
    uint8 staticBits = (clock_DR & (uint8)(~clock_MASK));
    clock_DR = staticBits | ((uint8)(value << clock_SHIFT) & clock_MASK);
}


/*******************************************************************************
* Function Name: clock_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void clock_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(clock_0, mode);
}


/*******************************************************************************
* Function Name: clock_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro clock_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 clock_Read(void) 
{
    return (clock_PS & clock_MASK) >> clock_SHIFT;
}


/*******************************************************************************
* Function Name: clock_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 clock_ReadDataReg(void) 
{
    return (clock_DR & clock_MASK) >> clock_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(clock_INTSTAT) 

    /*******************************************************************************
    * Function Name: clock_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 clock_ClearInterrupt(void) 
    {
        return (clock_INTSTAT & clock_MASK) >> clock_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
